@@ -1,5 +1,5 @@
 import matplotlib
-from matplotlib import pyplot
+from matplotlib import pyplot as plt
 from matplotlib.colors import rgb2hex
 
 ## Default colormap, other options here: http://www.scipy.org/Cookbook/Matplotlib/Show_colormaps
@@ -7,7 +7,7 @@ s = matplotlib.__version__.split('.')
 if int(s[0]) >= 2 or (int(s[0]) >= 1 and int(s[1]) >= 5):
     DEFAULT_COLOR_MAP_NAME = "viridis"
 else:
-    DEFAULT_COLOR_MAP_NAME = 'jet'
+    DEFAULT_COLOR_MAP_NAME = "jet"
 
 
 ## Matplotlib Colormapping ##
@@ -36,7 +36,7 @@ def get_cmap(cmap=None):
         cmap_name = cmap
     else:
         cmap_name = DEFAULT_COLOR_MAP_NAME
-    return pyplot.get_cmap(cmap_name)
+    return plt.get_cmap(cmap_name)
 
 
 def colormapper(value, lower=0, upper=1, cmap=None):
@@ -70,13 +70,13 @@ def colormapper(value, lower=0, upper=1, cmap=None):
     return hex_
 
 
-def colorbar_hack(ax, vmin, vmax, cmap, scientific=False, cbarlabel=None,
+def colorbar_hack(ax, vmin, vmax, cmap, scientific=False, cbarlabel=None, norm=None,
                   **kwargs):
     """
-    Colorbar hack to insert colorbar on ternary plot. 
-    
+    Colorbar hack to insert colorbar on ternary plot.
+
     Called by heatmap, not intended for direct usage.
-    
+
     Parameters
     ----------
     vmin: float
@@ -88,10 +88,11 @@ def colorbar_hack(ax, vmin, vmax, cmap, scientific=False, cbarlabel=None,
 
     """
     # http://stackoverflow.com/questions/8342549/matplotlib-add-colorbar-to-a-sequence-of-line-plots
-    norm = pyplot.Normalize(vmin=vmin, vmax=vmax)
-    sm = pyplot.cm.ScalarMappable(cmap=cmap, norm=norm)
+    if norm is None:
+        norm = plt.Normalize(vmin=vmin, vmax=vmax)
+    sm = plt.cm.ScalarMappable(cmap=cmap, norm=norm)
     sm._A = []
-    cb = pyplot.colorbar(sm, ax=ax, **kwargs)
+    cb = plt.colorbar(sm, ax=ax, **kwargs)
     if cbarlabel is not None:
         cb.set_label(cbarlabel)
     if scientific:
